package com.zehong.monitorreprotdatafrogovernment.task;

import com.zehong.monitorreprotdatafrogovernment.dao.JingyeDetectorInfoDao;
import com.zehong.monitorreprotdatafrogovernment.dao.YingdeDetectorInfoDao;
import com.zehong.monitorreprotdatafrogovernment.dao.ZhengyuanDetectorInfoDao;
import com.zehong.monitorreprotdatafrogovernment.entity.DetectorInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.Date;

@Configuration
@EnableScheduling
@PropertySource(value = "classpath:application.yml")
public class SaticScheduleTask {

    @Resource
    private JingyeDetectorInfoDao jingyeDetectorInfoDao;

    @Resource
    private YingdeDetectorInfoDao yingdeDetectorInfoDao;

    @Resource
    private ZhengyuanDetectorInfoDao zhengyuanDetectorInfoDao;

    @Autowired
    private SendSmsTask dynamicTask;

    @Value("${sendSmsCron}")
    private String sendSmsCron;

    @Scheduled(cron = "${cron}")
    private void configureTasks() {
        DetectorInfo jingye = jingyeDetectorInfoDao.getRecentSendData();
        compareReportDate(jingye.getUpdateTime(),"jingye");
        DetectorInfo yingde = yingdeDetectorInfoDao.getRecentSendData();
        compareReportDate(yingde.getUpdateTime(),"yingde");
        DetectorInfo zhengyuan = zhengyuanDetectorInfoDao.getRecentSendData();
        compareReportDate(zhengyuan.getUpdateTime(),"zhengyuan");
    }

    /**
     * 比较上报时间 超过五分钟为发送数据发送短信预警
     * @param reportDate 上报时间
     * @param company 公司
     */
    private void compareReportDate(Date reportDate,String company){
        long period = System.currentTimeMillis() - reportDate.getTime();
        //超过五分钟未发送数据发送短信报警
        if(5 < period/(60 * 1000)){
            //如未及时处理没半小时发送一次短信
            if(!dynamicTask.isExist(company)){
                //发送短信
                dynamicTask.sendSms(company);
                //启动定时半小时后重新发送
                dynamicTask.add(company,sendSmsCron);
            }
            return;
        }
        if (dynamicTask.isExist(company)){
            dynamicTask.stop(company);
        }
    }
}
